@@ -287,7 +287,7 @@ class ClUpdateAction(Action):
          'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
          },
         {'name': 'update_other:update_perl',
-         'group': __("Updating Perl"),
+         'group': __("Updating Perl modules"),
          'tasks': [
              {'name': 'update_other:perl_cleaner',
               'message': __('Find & rebuild packages and Perl header files '
@@ -343,7 +343,7 @@ class ClUpdateAction(Action):
               'message': __('Checking reverse dependencies'),
               'method': 'Update.revdep_rebuild("revdep-rebuild")',
               'condition': lambda Get: (Get(
-                  'cl_update_skip_rb_set') == 'off' and
+                  'cl_update_revdep_rebuild_set') == 'on' and
                   UpdateConditions.was_installed(
                       '.*', EmergeMark.RevdepRebuild)()),
               'decoration': 'Update.update_task("%s")' %
